import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'
import Layout from '@/layout'
import { loadView } from '@/store/modules/permission'
import store from '@/store'
import Cookies from 'js-cookie'

const user = {
  state: {
    token: getToken(),
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    specialTag: '',
    menuName: [],
    menus: []

  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_SPECIALTAG: (state, specialTag) => {
      state.specialTag = specialTag
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_MENUNAME: (state, menuName) => {
      state.menuName = menuName
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_MENUS: (state, menus) => {
      state.menus = menus
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      // const code = userInfo.code
      // const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password).then(res => {
          setToken(res.data)
          commit('SET_TOKEN', res.data)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo(state.token).then(res => {
          const user = res.data.user
          const avatar = user.avatar === null ? require('@/assets/image/profile.jpg') : user.avatar
          // if (res.data.roles && res.data.roles.length > 0) { // 验证返回的roles是否是一个非空数组
          //   commit('SET_ROLES', res.data.roles)
          // } else {
          //   commit('SET_ROLES', ['ROLE_DEFAULT'])
          // }
          commit('SET_ROLES', [])
          Cookies.set('role', res.data.roles)
          commit('SET_PERMISSIONS', res.data.permissions)
          Cookies.set('permissions', res.data.permissions)
          commit('SET_NAME', user.username)
          commit('SET_MENUS', res.data.menus)
          commit('SET_SPECIALTAG', user.specialTag)
          commit('SET_AVATAR', avatar)
          sessionStorage.setItem('userInfo', JSON.stringify(res.data))
          res.menuName = store.getters.menuName
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    GetInfoMessage({ commit, state }, menuName) {
      return new Promise((resolve, reject) => {
        commit('SET_MENUNAME', menuName) // 存入菜单名
        const b = menuName.join(',')
        Cookies.set('menuname', b)
        store.dispatch('tagsView/delAllViews').then(r => {})
        resolve(menuName)
      })
    },
    removeRole({ commit, state }) {
      return new Promise((resolve, reject) => {
        commit('SET_ROLES', '')
        resolve()
      })
    },
    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          commit('SET_MENUNAME', '')
          removeToken()
          sessionStorage.removeItem('userInfo')
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    }
  }
}

export default user
